@@ -1,4 +1,5 @@
-from repoze.formapi import marshalling
+from repoze.formapi.parser import parse
+from repoze.formapi.parser import missing
 
 import types
 import re
@@ -85,13 +86,13 @@ class Form(object):
             if params is not None:
                 raise ValueError(
                     "Can't provide both ``params`` and ``request``.")
-            params = request.params
+            params = request.params.items()
 
         # find action parameters
         action_params = {}
         if prefix is not None and params is not None:
             re_prefix = re.compile(r'^%s[._-](?P<name>.*)' % prefix)
-            for key, value in params.items():
+            for key, value in params:
                 if key == prefix:
                     action_params[None] = value
                 else:
@@ -116,12 +117,12 @@ class Form(object):
             prefix is None or \
             filter(None, actions) or \
             len(actions) == 0 and action_params.get(None) is not None):
-            params = params.items()
+            params = list(params)
         else:
             params = ()
 
-        # marshall request parameters
-        data, errors = marshalling.marshall(params, self.fields)
+        # Parse parameter input
+        data, errors = parse(params, self.fields)
 
         if len(params):
             self.data.update(data)
@@ -185,7 +186,7 @@ class Data(list):
             except KeyError:
                 continue
 
-            if value is not marshalling.missing:
+            if value is not missing:
                 return value
 
     def __setitem__(self, name, value):
